if ($Pref::Server::VehicleStatus::UseBullets $= "")
  $Pref::Server::VehicleStatus::UseBullets = 0;

if ($Pref::Server::VehicleStatus::Unit $= "")
  $Pref::Server::VehicleStatus::Unit = "mph";

if ($Pref::Server::VehicleStatus::BarLength $= "")
  $Pref::Server::VehicleStatus::BarLength = 32;

package VehicleStatusPackage
{
  function Armor::onMount(%this, %obj, %mount, %slot)
  {
    Parent::onMount(%this, %obj, %mount, %slot);

    if (!isFunction(%mount.getClassName(), "updateStatus"))
      return;

    if (!isEventPending(%mount.updateStatus) && isObject(%obj.client))
      %mount.updateStatus();
  }

  function Armor::onUnMount(%this, %obj, %mount, %slot)
  {
    Parent::onUnMount(%this, %obj, %mount, %slot);

    if (isEventPending(%mount.updateStatus) && isObject(%obj.client))
      commandToClient(%obj.client, 'ClearBottomPrint');
  }
};

activatePackage("VehicleStatusPackage");

function WheeledVehicle::updateStatus(%this)
{
  cancel(%this.updateStatus);

  %speed = vectorLen(%this.getVelocity());
  %factor = %speed / %this.getDataBlock().maxWheelSpeed;
  %unit = strUpr($Pref::Server::VehicleStatus::Unit);

  switch$ (%unit)
  {
  case "tps":
  case "bps":
    %speed *= 2;
  case "km/h":
    %speed = (%speed / 2.64) * 6 * 3600 / 3280.84;
  default:
    // Same formula used for mid-air kills
    %speed = (%speed / 2.64) * 6 * 3600 / 5280;
    %unit = "MPH";
  }

  %speed = mFloatLength(%speed, 0);

  %text = "<just:right><font:palatino linotype bold:48>\c3" @ %speed;
  %text = %text @ "<font:palatino linotype:32> \c6" @ %unit;
  %text = %text @ " \n<font:lucida console:24>\c3";

  %length = mClamp($Pref::Server::VehicleStatus::BarLength, 0, 42);
  %index = mFloatLength(%length * mClampF(%factor, 0, 1), 0);
  %char = $Pref::Server::VehicleStatus::UseBullets ? "\x95" : "\xD7";

  for (%i = 0; %i < %index; %i++)
    %text = %text @ %char;

  %text = %text @ "\c6";

  for (0; %i < %length; %i++)
    %text = %text @ "\xB7";

  %text = %text @ "<font:palatino linotype:32> \n";
  %count = %this.getDataBlock().numMountPoints;

  for (%i = 0; %i < %count; %i++)
  {
    %obj = %this.getMountedObject(%i);

    if (isObject(%obj.client))
    {
      %shown = 1;
      %obj.client.bottomPrint(%text, 1, 1);
    }
  }

  if (%shown)
    %this.updateStatus = %this.schedule(32, updateStatus);
}